@@ -51,11 +51,11 @@ CA <- function(Data, TypData = "f", TypMatrix = "I") {
     # de Correspondencia Multipla, ou seja, em 0 e 1, caso dados nominais
     NumLinha  <- nrow(Data)  # Numero de linhas na tabela
     for (k in 1:ncol(Data)) {
-      MConver   <- Data[,k] # Matriz com os dados para a conversao
-      Nivel     <- levels(MConver) # Nomes dos Niveis
-      Qtd_Nivel <- nlevels(MConver) # Quantidade de Niveis
+      MConver   <- as.factor(Data[,k]) # Matriz com os dados para a conversao
+      Nivel     <- levels(MConver)     # Nomes dos Niveis
+      Qtd_Nivel <- nlevels(MConver)    # Quantidade de Niveis
       MDummy = matrix(0,NumLinha,Qtd_Nivel) # Cria Matriz Vazia com elementos zero
-      colnames(MDummy) <- (Nivel) # Nomeia as colunas
+      colnames(MDummy) <- (Nivel)      # Nomeia as colunas
       for (i in 1:Qtd_Nivel)
         for ( j in 1:NumLinha)
           if (MConver[j]==Nivel[i]) MDummy[j,i] = 1
